/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.utils;

import org.fortiss.af3.platform.raspberry.model.Actuator;
import org.fortiss.af3.platform.raspberry.model.ActuatorOut;
import org.fortiss.af3.platform.raspberry.model.Bus;
import org.fortiss.af3.platform.raspberry.model.BusMasterInterface;
import org.fortiss.af3.platform.raspberry.model.BusMasterPort;
import org.fortiss.af3.platform.raspberry.model.CANBus;
import org.fortiss.af3.platform.raspberry.model.CANBusMasterInterface;
import org.fortiss.af3.platform.raspberry.model.CANBusMasterPort;
import org.fortiss.af3.platform.raspberry.model.Core;
import org.fortiss.af3.platform.raspberry.model.ModelFactory;
import org.fortiss.af3.platform.raspberry.model.RaspberryPi3;
import org.fortiss.af3.platform.raspberry.model.Sensor;
import org.fortiss.af3.platform.raspberry.model.SensorIn;
import org.fortiss.tooling.base.utils.LayoutModelElementFactory;

/**
 * 
 * @author chaudhary
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash:
 */
public class RaspberryModelElementFactory {

	public static CANBusMasterPort createCANBusMasterPort(String name) {
		CANBusMasterPort canBusMasterPort = ModelFactory.eINSTANCE.createCANBusMasterPort();
		canBusMasterPort.setName(name);
		LayoutModelElementFactory.createConnectorLayout(canBusMasterPort);
		return canBusMasterPort;
	}

	public static CANBusMasterInterface createCANBusMasterInterface(String name) {
		CANBusMasterInterface canBusMasterInterface =
				ModelFactory.eINSTANCE.createCANBusMasterInterface();
		canBusMasterInterface.setName(name);
		LayoutModelElementFactory.createConnectorLayout(canBusMasterInterface);
		return canBusMasterInterface;
	}

	public static BusMasterPort createBusMasterPort(String name) {
		BusMasterPort busMasterPort = ModelFactory.eINSTANCE.createBusMasterPort();
		busMasterPort.setName(name);
		LayoutModelElementFactory.createConnectorLayout(busMasterPort);
		return busMasterPort;
	}

	public static BusMasterInterface createBusMasterInterface(String name) {
		BusMasterInterface busMasterInterface = ModelFactory.eINSTANCE.createBusMasterInterface();
		busMasterInterface.setName(name);
		LayoutModelElementFactory.createConnectorLayout(busMasterInterface);
		return busMasterInterface;
	}

	/** Creates a Hardware Board. */
	public static RaspberryPi3 createRaspberryPi3(String name) {
		RaspberryPi3 raspberryPi3 = ModelFactory.eINSTANCE.createRaspberryPi3();
		raspberryPi3.setName(name);
		LayoutModelElementFactory.createNodeElementLayout(raspberryPi3);
		return raspberryPi3;
	}

	/** Creates a Core with a given name. */
	public static Core createCore(String name) {
		Core core = ModelFactory.eINSTANCE.createCore();
		core.setName(name);
		LayoutModelElementFactory.createNodeElementLayout(core);
		return core;
	}

	/** Creates a Bus with a given name. */
	public static Bus createBus(String name) {
		Bus bus = ModelFactory.eINSTANCE.createBus();
		bus.setName(name);
		LayoutModelElementFactory.createConnectionLayout(bus);
		return bus;
	}

	/** Creates a Bus with a given name. */
	public static CANBus createCANBus(String name) {
		CANBus canBus = ModelFactory.eINSTANCE.createCANBus();
		canBus.setName(name);
		LayoutModelElementFactory.createConnectionLayout(canBus);
		return canBus;
	}

	public static Sensor createSensor(String name) {
		Sensor sensor = ModelFactory.eINSTANCE.createSensor();
		sensor.setName(name);
		LayoutModelElementFactory.createNodeElementLayout(sensor);
		return sensor;
	}

	public static SensorIn createSensorIn(String name) {
		SensorIn sensorIn = ModelFactory.eINSTANCE.createSensorIn();
		sensorIn.setName(name);
		LayoutModelElementFactory.createNodeElementLayout(sensorIn);
		return sensorIn;
	}

	public static Actuator createActuator(String name) {
		Actuator actuator = ModelFactory.eINSTANCE.createActuator();
		actuator.setName(name);
		LayoutModelElementFactory.createNodeElementLayout(actuator);
		return actuator;
	}

	public static ActuatorOut createActuatorOut(String name) {
		ActuatorOut actuatorOut = ModelFactory.eINSTANCE.createActuatorOut();
		actuatorOut.setName(name);
		LayoutModelElementFactory.createNodeElementLayout(actuatorOut);
		return actuatorOut;
	}

}
